==> sqlstreamstore-browser-0.1.55.tgz: package/src/stream-store/actions.ts <==
import { Action, Location } from 'history';
import { createAction } from './../reactive';
import { ReplaySubject } from 'rxjs';
import { HttpRequest, HttpResponse } from './../types';
import { history, http } from './../utils';

type Actions = {
    [P in keyof typeof http]: {
        request: ReplaySubject<HttpRequest>;
        response: ReplaySubject<HttpResponse>;
    }
};

type HttpVerb = keyof typeof http;

const verbs: HttpVerb[] = Object.keys(http) as HttpVerb[];

const actions: Actions = verbs.reduce(
    (akk, verb: keyof typeof http) => ({
        ...akk,
        [verb]: {
            request: createAction(),
            response: createAction(),
        },
    }),
    // tslint:disable-next-line:no-object-literal-type-assertion
    {} as Actions,
);

verbs.forEach(verb =>
    actions[verb].request
        .flatMap(request => http[verb](request))
        .subscribe(response => actions[verb].response.next(response)),
);

let rewriteMethod = (link: string) => link;

export const setUrlRewriteFunc = (action: (link: string) => string) => {
    rewriteMethod = action;
}

actions.get.response.subscribe(({ url }) => history.push(rewriteMethod(url)));

const getUrl = (location: Location) =>
    `${location.pathname}${location.search}${location.hash}`;

history.listen(
    (location: Location, action: Action): void => {

        console.log('history listen')

        if (action !== 'POP') {
            return;
        }
        actions.get.request.next({
            headers: {},
            link: { href: getUrl(location) },
        });
    },
);

export default actions;

==> sqlstreamstore-browser-0.1.74.tgz: package/src/stream-store/actions.ts <==
import { Action, Location } from 'history';
import { ReplaySubject } from 'rxjs';
import { createAction } from './../reactive';
import { HttpRequest, HttpResponse } from './../types';
import { history, http } from './../utils';

type Actions = {
    [P in keyof typeof http]: {
        request: ReplaySubject<HttpRequest>;
        response: ReplaySubject<HttpResponse>;
    }
};

type HttpVerb = keyof typeof http;

const verbs: HttpVerb[] = Object.keys(http) as HttpVerb[];

const actions: Actions = verbs.reduce(
    (akk, verb: keyof typeof http) => ({
        ...akk,
        [verb]: {
            request: createAction(),
            response: createAction(),
        },
    }),
    // tslint:disable-next-line:no-object-literal-type-assertion
    {} as Actions,
);

const urlParamName = 'storeUrl';

verbs.forEach(verb =>
    actions[verb].request
        .flatMap(request => http[verb](request))
        .subscribe(response => actions[verb].response.next(response)),
);

actions.get.response.subscribe(({ url }) => {
    const currentUrl = window.location.href.split('?')[0];
    history.push(`${currentUrl}?${urlParamName}=${url}`);
});

history.listen(
    (location: Location, action: Action): void => {
        if (action !== 'POP') {
            return;
        }

        const urlParams = new URLSearchParams(location.search);
        const storeUrl = urlParams.get(urlParamName);

        if (storeUrl != null) {
            actions.get.request.next({
                headers: {},
                link: { href: storeUrl },
            });
        }
    },
);

export default actions;
